@@ -10,12 +10,12 @@
 ## Configuration
 # Commands
 $WGET = "/usr/bin/wget";
-$LYNX = "NO";
+$LYNX = "/usr/bin/lynx";
 #$SED = "/bin/sed";
 $GREP = "/bin/grep";
 $RECODE = "NO"; #"/usr/bin/recode"; -- dont use recode, it is not widely available
 # Directories
-$prefix="/home/cs/usr";
+$prefix="/home/cs/onlinebanking";
 $datadir="${prefix}/share";
 $pkgdatadir="$datadir/ktoblzcheck";
 $BANKDATADIR="${pkgdatadir}";
@@ -36,8 +36,8 @@ die "The directory for the bankdata \"$BANKDATADIR\" is not writable. You need t
 ## Common constants
 $debug=0; # set this to nonzero for activating debugging mode
 $BASE_URL="http://www.bundesbank.de";
-$MAIN_URL="$BASE_URL/zahlungsverkehr";
-$MAIN_DOC="$MAIN_URL/zahlungsverkehr_bankleitzahlen_download.php";
+$MAIN_URL="$BASE_URL";
+$MAIN_DOC="$MAIN_URL/Redaktion/DE/Standardartikel/Kerngeschaeftsfelder/Unbarer_Zahlungsverkehr/bankleitzahlen_download.html";
 
 if ($debug == 0) {
   if ($WGET ne "NO") {
@@ -51,8 +51,10 @@ if ($debug == 0) {
 }
 # Old regexp before 2006-06-04
 #$datafile_regexp = 'blz\d{4,8}?pc\.txt';
-# New regexp from 2006-06-05 onwards
-$datafile_regexp = 'blz_\d{8}\.txt';
+# Regexp from 2006-06-05 onwards
+#$datafile_regexp = 'blz_\d{8}\.txt';
+# New regexp from 2012-05-30 onwards
+$datafile_regexp = 'blz_\d{4}_\d{2}_\d{2}_txt\.txt';
 
 ## Find the available potential download files
 @potential_files = ();
@@ -97,7 +99,7 @@ if (scalar @diff == 0) {
   $k = 0;
   foreach $e (@diff) { print " [".$k++."] ".$e."\n"; };
   print "Which one should be chosen? (Hint: The file names contain \n".
-    "the four-digit year, the month and the date as YYYYMMDD. You should \n".
+    "the four-digit year, the month and the date as YYYY_MM_DD. You should \n".
       "probably choose the file that corresponds to a date that \n".
 	"lies in the future.) \n".
 	  "Please type the corresponding number and press Enter.\n";
@@ -114,7 +116,7 @@ if (scalar @diff == 0) {
 # "blz_20110102" will be installed after conversion as
 # "bankdata_20110102".
 $INSTALLED_NAME = $file;
-$INSTALLED_NAME =~ s/blz/bankdata/gio;
+$INSTALLED_NAME =~ s/blz_(\d{4})_(\d{2})_(\d{2})_txt\.txt/bankdata_\1\2\3.txt/gio;
 
 $download = "$MAIN_URL/$correct_url";
 $install_1 = "$BANKDATADIR/$file";
@@ -156,9 +158,10 @@ if (system("$GREP -q 10000000 $install_1") != 0) {
   die "Downloaded file $install_1 is not in valid BLZ format. Aborting.";
 }
 
-## 3. Backup copy of old bankdata file
-print "$ECHO cp $install_2 $install_2~\n";
-system("$ECHO cp $install_2 $install_2~");# || die "can't call system: $!";
+### 3. Backup copy of old bankdata file
+#print "$ECHO cp $install_2 $install_2~\n";
+#system("$ECHO cp $install_2 $install_2~");# || die "can't call system: $!";
+# - no backup needed anymore because all files have different dates in the name
 
 ## 4. Recode the downloaded file from its latin1 encoding into the
 ## locale encoding
