@@ -1,6 +1,6 @@
 # -*- encoding: latin1 -*-
 #
-# cvs         : $Id: ktoblzcheck.py,v 1.4 2006/10/29 20:45:43 cstim Exp $
+# cvs         : $Id$
 # begin       : Tue Apr 19 2005
 # copyright   : (C) 2005 by Andreas Degert
 # email       : ad@papyrus-gmbh.de
@@ -194,39 +194,3 @@ kto.IbanCheck_resultText.argtypes = c_int,
 kto.IbanCheck_bic_position.restype = c_int
 kto.IbanCheck_bic_position.argtypes = (
     c_void_p, c_char_p, POINTER(c_int), POINTER(c_int))
-
-def test():
-    a = AccountNumberCheck()
-    print 'Number of Banks:', a.bankCount
-    print 'find 20010020:', a.findBank('20010020')
-    print 'find 20010033:', a.findBank('20010033')
-    print 'check 20070024/9291394:', a.check('20070024','9291394')
-    print 'check 20070024/9291394:', a.check('20070024','9291394023')
-    print
-    ck = IbanCheck()
-    if not kto.IbanCheck_selftest(ck):  # not publicly defined
-	print "Self-Test failed!"
-	raise SystemExit
-    s = " iban fr14 2004 1010 0505 0001 3m02 606"
-    print "test for iban    :", s
-    iban = Iban(s)
-    print "transmission form:", iban.transmissionForm()
-    res = ck.check(iban)
-    print "check result     :", res, "("+IbanCheck.resultText(res)+")"
-    print "printable form   :", iban.printableForm()
-    print
-    print "expect bad checksum:"
-    s = "FR1420041010050500013X02606"
-    res = ck.check(s)
-    print s + ":", res, "("+IbanCheck.resultText(res)+")"
-    print
-    s = "IBAN DE66 2007 0024 0929 1394 00"
-    print s
-    s = Iban(s).transmissionForm()
-    start, end = ck.bic_position(s)
-    print "prefix, checksum, BIC, account:"
-    print ', '.join((s[:2], s[2:4], s[start:end], s[end:].lstrip('0')))
-
-
-if __name__ == '__main__':
-    test()
